@@ -17,7 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2012 Red Hat, Inc.
+ * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
 #ifndef __CE_PAGE_H__
@@ -28,10 +28,8 @@
 
 #include <gtk/gtk.h>
 
-#include <dbus/dbus-glib.h>
-#include <nm-connection.h>
-#include <nm-client.h>
-#include <nm-remote-settings.h>
+#include <NetworkManager.h>
+
 #include "nm-connection-editor.h"
 #include "utils.h"
 
@@ -47,7 +45,7 @@ typedef GSList * (*PageGetConnectionsFunc) (gpointer user_data);
 
 typedef void (*PageNewConnectionFunc) (GtkWindow *parent,
                                        const char *detail,
-                                       NMRemoteSettings *settings,
+                                       NMClient *client,
                                        PageNewConnectionResultFunc result_func,
                                        gpointer user_data);
 
@@ -71,14 +69,12 @@ typedef struct {
 	GtkWidget *page;
 	char *title;
 
-	DBusGProxy *proxy;
 	gulong secrets_done_validate;
 
 	NMConnectionEditor *editor;
 	NMConnection *connection;
 	GtkWindow *parent_window;
 	NMClient *client;
-	NMRemoteSettings *settings;
 } CEPage;
 
 typedef struct {
@@ -99,7 +95,6 @@ typedef CEPage* (*CEPageNewFunc)(NMConnectionEditor *editor,
                                  NMConnection *connection,
                                  GtkWindow *parent,
                                  NMClient *client,
-                                 NMRemoteSettings *settings,
                                  const char **out_secrets_setting_name,
                                  GError **error);
 
@@ -115,26 +110,23 @@ gboolean ce_page_last_update (CEPage *self, NMConnection *connection, GError **e
 gboolean ce_page_inter_page_change (CEPage *self);
 
 void ce_page_setup_mac_combo (CEPage *self, GtkComboBox *combo,
-                              const GByteArray *mac, int type, char **mac_list);
+                              const char *mac, char **mac_list);
 void ce_page_setup_data_combo (CEPage *self, GtkComboBox *combo,
                                const char *data, char **list);
 void ce_page_setup_device_combo (CEPage *self,
                                  GtkComboBox *combo,
                                  GType device_type,
                                  const char *ifname,
-                                 const GByteArray *mac,
-                                 int mac_type,
+                                 const char *mac,
                                  const char *mac_property,
                                  gboolean ifname_first);
 gboolean ce_page_mac_entry_valid (GtkEntry *entry, int type, const char *property_name, GError **error);
 gboolean ce_page_interface_name_valid (const char *iface, const char *property_name, GError **error);
 gboolean ce_page_device_entry_get (GtkEntry *entry, int type,
                                    gboolean check_ifname,
-                                   char **ifname, GByteArray **mac,
+                                   char **ifname, char **mac,
                                    const char *device_name,
                                    GError **error);
-void ce_page_mac_to_entry (const GByteArray *mac, int type, GtkEntry *entry);
-GByteArray *ce_page_entry_to_mac (GtkEntry *entry, int type, gboolean *invalid);
 
 void ce_page_changed (CEPage *self);
 
@@ -146,18 +138,18 @@ int ce_get_property_default (NMSetting *setting, const char *property_name);
 
 void ce_page_complete_init (CEPage *self,
                             const char *setting_name,
-                            GHashTable *secrets,
+                            GVariant *secrets,
                             GError *error);
 
 gboolean ce_page_get_initialized (CEPage *self);
 
-char *ce_page_get_next_available_name (GSList *connections, const char *format);
+char *ce_page_get_next_available_name (const GPtrArray *connections, const char *format);
 
 /* Only for subclasses */
 NMConnection *ce_page_new_connection (const char *format,
                                       const char *ctype,
                                       gboolean autoconnect,
-                                      NMRemoteSettings *settings,
+                                      NMClient *client,
                                       gpointer user_data);
 
 CEPage *ce_page_new (GType page_type,
@@ -165,7 +157,6 @@ CEPage *ce_page_new (GType page_type,
                      NMConnection *connection,
                      GtkWindow *parent_window,
                      NMClient *client,
-                     NMRemoteSettings *settings,
                      const char *ui_file,
                      const char *widget_name,
                      const char *title);
