@@ -20,15 +20,12 @@
  * Copyright 2013 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 #include <errno.h>
 #include <stdlib.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "page-dcb.h"
 
 G_DEFINE_TYPE (CEPageDcb, ce_page_dcb, CE_TYPE_PAGE)
