@@ -20,13 +20,10 @@
  * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-
 #include "wireless-security.h"
 #include "page-wifi.h"
 #include "page-wifi-security.h"
