@@ -22,10 +22,7 @@
  *          Dan Williams <dcbw@redhat.com>
  */
 
-#include <config.h>
-
-#include <glib/gi18n-lib.h>
-#include <gtk/gtk.h>
+#include "nm-default.h"
 
 #include "nma-vpn-password-dialog.h"
 
@@ -40,7 +37,7 @@ typedef struct {
 	gboolean show_password;
 	gboolean show_password_secondary;
 	gboolean show_password_ternary;
-	
+
 	/* Internal widgetry and flags */
 	GtkWidget *password_entry;
 	GtkWidget *password_entry_secondary;
@@ -50,7 +47,7 @@ typedef struct {
 	GtkWidget *grid_alignment;
 	GtkWidget *grid;
 	GtkSizeGroup *group;
-	
+
 	char *primary_password_label;
 	char *secondary_password_label;
 	char *ternary_password_label;
