@@ -20,12 +20,10 @@
  * Copyright 2007 - 2015 Red Hat, Inc.
  */
 
-#include <config.h>
+#include "nm-default.h"
+
 #include <string.h>
 #include <netinet/ether.h>
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
 
 #include "utils.h"
 
@@ -60,7 +58,7 @@ utils_ether_addr_valid (const struct ether_addr *test_addr)
 
 	if (test_addr->ether_addr_octet[0] & 1)			/* Multicast addresses */
 		return FALSE;
-	
+
 	return TRUE;
 }
 
