@@ -20,9 +20,10 @@
  * Copyright 2007 - 2014 Red Hat, Inc.
  */
 
+#include "nm-default.h"
+
 #include <ctype.h>
 #include <string.h>
-#include <glib/gi18n.h>
 
 #include "eap-method.h"
 #include "wireless-security.h"
